@@ -21,24 +21,29 @@
  */
 #include "config.h"
 
-#include <string.h>
-
-#include <glib/gi18n.h>
+#include "seahorse-gpgme.h"
+#include "seahorse-gpgme-exporter.h"
+#include "seahorse-gpgme-key-op.h"
+#include "seahorse-gpgme-key-deleter.h"
+#include "seahorse-gpgme-photo.h"
+#include "seahorse-gpgme-keyring.h"
+#include "seahorse-gpgme-secret-deleter.h"
+#include "seahorse-gpgme-uid.h"
+#include "seahorse-pgp-actions.h"
+#include "seahorse-pgp-backend.h"
+#include "seahorse-pgp-key.h"
 
+#include "seahorse-deletable.h"
+#include "seahorse-exportable.h"
 #include "seahorse-icons.h"
 #include "seahorse-predicate.h"
 #include "seahorse-object-list.h"
 #include "seahorse-place.h"
 #include "seahorse-util.h"
 
-#include "seahorse-pgp-actions.h"
-#include "seahorse-pgp-backend.h"
-#include "pgp/seahorse-pgp-key.h"
-#include "pgp/seahorse-gpgme.h"
-#include "pgp/seahorse-gpgme-key-op.h"
-#include "pgp/seahorse-gpgme-photo.h"
-#include "pgp/seahorse-gpgme-keyring.h"
-#include "pgp/seahorse-gpgme-uid.h"
+#include <glib/gi18n.h>
+
+#include <string.h>
 
 enum {
 	PROP_0,
@@ -48,7 +53,14 @@ enum {
 	PROP_TRUST
 };
 
-G_DEFINE_TYPE (SeahorseGpgmeKey, seahorse_gpgme_key, SEAHORSE_TYPE_PGP_KEY);
+static void       seahorse_gpgme_key_deletable_iface       (SeahorseDeletableIface *iface);
+
+static void       seahorse_gpgme_key_exportable_iface      (SeahorseExportableIface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (SeahorseGpgmeKey, seahorse_gpgme_key, SEAHORSE_TYPE_PGP_KEY,
+                         G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_EXPORTABLE, seahorse_gpgme_key_exportable_iface);
+                         G_IMPLEMENT_INTERFACE (SEAHORSE_TYPE_DELETABLE, seahorse_gpgme_key_deletable_iface);
+);
 
 struct _SeahorseGpgmeKeyPrivate {
 	gpgme_key_t pubkey;   		/* The public key */
@@ -506,8 +518,8 @@ seahorse_gpgme_key_object_finalize (GObject *obj)
 	g_assert (self->pv->pubkey == NULL);
 	g_assert (self->pv->seckey == NULL);
 	g_assert (self->pv->uids == NULL);
-    
-	G_OBJECT_CLASS (seahorse_gpgme_key_parent_class)->finalize (obj);
+
+	G_OBJECT_CLASS (seahorse_gpgme_key_parent_class)->finalize (G_OBJECT (self));
 }
 
 static void
@@ -544,6 +556,40 @@ seahorse_gpgme_key_class_init (SeahorseGpgmeKeyClass *klass)
         g_object_class_override_property (gobject_class, PROP_TRUST, "trust");
 }
 
+static SeahorseDeleter *
+seahorse_gpgme_key_create_deleter (SeahorseDeletable *deletable)
+{
+	SeahorseGpgmeKey *self = SEAHORSE_GPGME_KEY (deletable);
+	if (self->pv->seckey)
+		return seahorse_gpgme_secret_deleter_new (self);
+	else
+		return seahorse_gpgme_key_deleter_new (self);
+}
+
+static void
+seahorse_gpgme_key_deletable_iface (SeahorseDeletableIface *iface)
+{
+	iface->create_deleter = seahorse_gpgme_key_create_deleter;
+}
+
+static GList *
+seahorse_gpgme_key_create_exporters (SeahorseExportable *exportable,
+                                     SeahorseExporterType type)
+{
+	GList *result = NULL;
+
+	if (type != SEAHORSE_EXPORTER_TEXTUAL)
+		result = g_list_append (result, seahorse_gpgme_exporter_new (G_OBJECT (exportable), FALSE, FALSE));
+	result = g_list_append (result, seahorse_gpgme_exporter_new (G_OBJECT (exportable), TRUE, FALSE));
+
+	return result;
+}
+
+static void
+seahorse_gpgme_key_exportable_iface (SeahorseExportableIface *iface)
+{
+	iface->create_exporters = seahorse_gpgme_key_create_exporters;
+}
 
 /* -----------------------------------------------------------------------------
  * PUBLIC 
