@@ -64,6 +64,7 @@ void           on_keymanager_import_button              (GtkButton* button,
 
 struct _SeahorseKeyManagerPrivate {
 	GtkActionGroup* view_actions;
+	GtkRadioAction *show_action;
 	GtkEntry* filter_entry;
 	SeahorsePredicate pred;
 	SeahorseSidebar *sidebar;
@@ -82,7 +83,7 @@ enum  {
 	TARGETS_URIS
 };
 
-G_DEFINE_TYPE (SeahorseKeyManager, seahorse_key_manager, SEAHORSE_TYPE_VIEWER);
+G_DEFINE_TYPE (SeahorseKeyManager, seahorse_key_manager, SEAHORSE_TYPE_CATALOG);
 
 /* -----------------------------------------------------------------------------
  * INTERNAL 
@@ -121,7 +122,7 @@ on_keymanager_row_activated (GtkTreeView* view, GtkTreePath* path,
 	
 	obj = seahorse_key_manager_store_get_object_from_path (view, path);
 	if (obj != NULL)
-		seahorse_viewer_show_properties (SEAHORSE_VIEWER (self), obj);
+		seahorse_catalog_show_properties (SEAHORSE_CATALOG (self), obj);
 }
 
 G_MODULE_EXPORT gboolean
@@ -131,8 +132,8 @@ on_keymanager_key_list_button_pressed (GtkTreeView* view, GdkEventButton* event,
 	g_return_val_if_fail (GTK_IS_TREE_VIEW (view), FALSE);
 	
 	if (event->button == 3)
-		seahorse_viewer_show_context_menu (SEAHORSE_VIEWER (self),
-		                                   SEAHORSE_VIEWER_MENU_OBJECT,
+		seahorse_catalog_show_context_menu (SEAHORSE_CATALOG (self),
+		                                   SEAHORSE_CATALOG_MENU_OBJECT,
 		                                   event->button, event->time);
 
 	return FALSE;
@@ -143,10 +144,10 @@ on_keymanager_key_list_popup_menu (GtkTreeView* view, SeahorseKeyManager* self)
 {
 	GList *objects;
 
-	objects = seahorse_viewer_get_selected_objects (SEAHORSE_VIEWER (self));
+	objects = seahorse_catalog_get_selected_objects (SEAHORSE_CATALOG (self));
 	if (objects != NULL)
-		seahorse_viewer_show_context_menu (SEAHORSE_VIEWER (self),
-		                                   SEAHORSE_VIEWER_MENU_OBJECT,
+		seahorse_catalog_show_context_menu (SEAHORSE_CATALOG (self),
+		                                   SEAHORSE_CATALOG_MENU_OBJECT,
 		                                   0, gtk_get_current_event_time ());
 	g_list_free (objects);
 	return FALSE;
@@ -157,7 +158,7 @@ on_file_new (GtkAction* action, SeahorseKeyManager* self)
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_ACTION (action));
-	seahorse_generate_select_show (seahorse_viewer_get_window (SEAHORSE_VIEWER (self)));
+	seahorse_generate_select_show (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)));
 }
 
 G_MODULE_EXPORT void 
@@ -165,7 +166,7 @@ on_keymanager_new_button (GtkButton* button, SeahorseKeyManager* self)
 {
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 	g_return_if_fail (GTK_IS_BUTTON (button));
-	seahorse_generate_select_show (seahorse_viewer_get_window (SEAHORSE_VIEWER (self)));
+	seahorse_generate_select_show (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)));
 }
 
 #if REFACTOR_FIRST
@@ -215,7 +216,7 @@ import_files (SeahorseKeyManager* self,
 	GtkDialog *dialog;
 	GtkWindow *parent;
 
-	parent = seahorse_viewer_get_window (SEAHORSE_VIEWER (self));
+	parent = seahorse_catalog_get_window (SEAHORSE_CATALOG (self));
 	dialog = seahorse_import_dialog_new (parent);
 	seahorse_import_dialog_add_uris (SEAHORSE_IMPORT_DIALOG (dialog), uris);
 
@@ -226,17 +227,68 @@ import_files (SeahorseKeyManager* self,
 static void 
 import_prompt (SeahorseKeyManager* self) 
 {
-	GtkDialog* dialog;
+	GtkFileFilter *filter;
+	GtkWidget *dialog;
 	gchar *uris[2];
-	gchar* uri;
+	gchar *uri = NULL;
 
 	g_return_if_fail (SEAHORSE_IS_KEY_MANAGER (self));
 
-	dialog = seahorse_util_chooser_open_new (_("Import Key"), 
-	                                         seahorse_viewer_get_window (SEAHORSE_VIEWER (self)));
-	seahorse_util_chooser_show_key_files (dialog);
-	
-	uri = seahorse_util_chooser_open_prompt (dialog);
+	dialog = gtk_file_chooser_dialog_new (_("Import Key"),
+	                                      seahorse_catalog_get_window (SEAHORSE_CATALOG (self)),
+	                                      GTK_FILE_CHOOSER_ACTION_OPEN,
+	                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+	                                      NULL);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
+
+	/* TODO: This should come from libgcr somehow */
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All key files"));
+	gtk_file_filter_add_mime_type (filter, "application/pgp-keys");
+	gtk_file_filter_add_mime_type (filter, "application/x-ssh-key");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs12");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs12+pem");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs7-mime");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs7-mime+pem");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs8");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs8+pem");
+	gtk_file_filter_add_mime_type (filter, "application/pkix-cert");
+	gtk_file_filter_add_mime_type (filter, "application/pkix-cert+pem");
+	gtk_file_filter_add_mime_type (filter, "application/pkix-crl");
+	gtk_file_filter_add_mime_type (filter, "application/pkix-crl+pem");
+	gtk_file_filter_add_mime_type (filter, "application/x-pem-file");
+	gtk_file_filter_add_mime_type (filter, "application/x-pem-key");
+	gtk_file_filter_add_mime_type (filter, "application/x-pkcs12");
+	gtk_file_filter_add_mime_type (filter, "application/x-pkcs7-certificates");
+	gtk_file_filter_add_mime_type (filter, "application/x-x509-ca-cert");
+	gtk_file_filter_add_mime_type (filter, "application/x-x509-user-cert");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs10");
+	gtk_file_filter_add_mime_type (filter, "application/pkcs10+pem");
+	gtk_file_filter_add_mime_type (filter, "application/x-spkac");
+	gtk_file_filter_add_mime_type (filter, "application/x-spkac+base64");
+	gtk_file_filter_add_pattern (filter, "*.asc");
+	gtk_file_filter_add_pattern (filter, "*.gpg");
+	gtk_file_filter_add_pattern (filter, "*.pub");
+	gtk_file_filter_add_pattern (filter, "*.pfx");
+	gtk_file_filter_add_pattern (filter, "*.cer");
+	gtk_file_filter_add_pattern (filter, "*.crt");
+	gtk_file_filter_add_pattern (filter, "*.pem");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
+
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All files"));
+	gtk_file_filter_add_pattern (filter, "*");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+		uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (dialog));
+
+	gtk_widget_destroy (dialog);
+
 	if (uri != NULL) {
 		uris[0] = uri;
 		uris[1] = NULL;
@@ -270,7 +322,7 @@ import_text (SeahorseKeyManager* self,
 	GtkDialog *dialog;
 	GtkWindow *parent;
 
-	parent = seahorse_viewer_get_window (SEAHORSE_VIEWER (self));
+	parent = seahorse_catalog_get_window (SEAHORSE_CATALOG (self));
 	dialog = seahorse_import_dialog_new (parent);
 	seahorse_import_dialog_add_text (SEAHORSE_IMPORT_DIALOG (dialog),
 	                                 display_name, text);
@@ -361,16 +413,13 @@ on_delete_event (GtkWidget* widget, GdkEvent* event, SeahorseKeyManager* self)
 	return TRUE;
 }
 
-static void
-on_view_show_changed (GtkRadioAction *action,
-                      GtkRadioAction *current,
-                      gpointer user_data)
+static const gchar *
+update_view_filter (SeahorseKeyManager *self)
 {
-	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (user_data);
-	const gchar *value;
+	const gchar *value = "";
 	gint radio;
 
-	radio = gtk_radio_action_get_current_value (action);
+	radio = gtk_radio_action_get_current_value (self->pv->show_action);
 	switch (radio) {
 	case SHOW_PERSONAL:
 		self->pv->pred.flags = SEAHORSE_FLAG_PERSONAL;
@@ -387,6 +436,17 @@ on_view_show_changed (GtkRadioAction *action,
 	}
 
 	seahorse_key_manager_store_refilter (self->pv->store);
+	return value;
+}
+
+
+static void
+on_view_show_changed (GtkRadioAction *action,
+                      GtkRadioAction *current,
+                      gpointer user_data)
+{
+	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (user_data);
+	const gchar *value = update_view_filter (self);
 	g_settings_set_string (self->pv->settings, "item-filter", value);
 }
 
@@ -395,7 +455,7 @@ on_item_filter_changed (GSettings *settings,
                         const gchar *key,
                         gpointer user_data)
 {
-	GtkAction* action = GTK_ACTION (user_data);
+	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (user_data);
 	gchar *value;
 	gint radio;
 
@@ -407,9 +467,9 @@ on_item_filter_changed (GSettings *settings,
 	else if (g_str_equal (value, "trusted"))
 		radio = SHOW_TRUSTED;
 	else
-		action = NULL;
-	if (action != NULL)
-		gtk_radio_action_set_current_value (GTK_RADIO_ACTION (action), radio);
+		radio = -1;
+	gtk_radio_action_set_current_value (self->pv->show_action, radio);
+	update_view_filter (self);
 	g_free (value);
 }
 
@@ -460,58 +520,48 @@ static const GtkRadioActionEntry VIEW_RADIO_ACTIONS[] = {
 	  N_("Only show personal keys, certificates and passwords"), SHOW_PERSONAL },
 	{ "view-trusted", NULL, N_("Show _trusted"), NULL,
 	  N_("Only show trusted keys, certificates and passwords"), SHOW_TRUSTED },
-	{ "view-any", NULL, N_("_Show _any"), NULL,
+	{ "view-any", NULL, N_("Show _any"), NULL,
 	  N_("Show all keys, certificates and passwords"), SHOW_ANY },
 };
 
 static GList *
-seahorse_key_manager_get_selected_objects (SeahorseViewer* viewer)
+seahorse_key_manager_get_selected_objects (SeahorseCatalog *catalog)
 {
-	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (viewer);
+	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (catalog);
 	return seahorse_key_manager_store_get_selected_objects (self->pv->view);
 }
 
-static GList *
-seahorse_key_manager_get_selected_places (SeahorseViewer* viewer)
+static SeahorsePlace *
+seahorse_key_manager_get_focused_place (SeahorseCatalog *catalog)
 {
-	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (viewer);
-	return seahorse_sidebar_get_selected_places (self->pv->sidebar);
-}
-
-static GList *
-seahorse_key_manager_get_selected_backends (SeahorseViewer* viewer)
-{
-	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (viewer);
-	return seahorse_sidebar_get_backends (self->pv->sidebar);
+	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (catalog);
+	return seahorse_sidebar_get_focused_place (self->pv->sidebar);
 }
 
 static gboolean
-on_idle_save_sidebar_width (gpointer user_data)
+on_panes_realize (GtkWidget *widget,
+                  gpointer   user_data)
 {
 	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (user_data);
+	gint width;
 
-	self->pv->sidebar_width_sig = 0;
-	g_settings_set_int (self->pv->settings, "sidebar-width", self->pv->sidebar_width);
+	width = g_settings_get_int (self->pv->settings, "sidebar-width");
+	gtk_paned_set_position (GTK_PANED (widget), width);
 
 	return FALSE;
 }
 
-static void
-on_sidebar_panes_size_allocate (GtkWidget *widget,
-                                GtkAllocation *allocation,
-                                gpointer user_data)
+static gboolean
+on_panes_unrealize (GtkWidget *widget,
+                    gpointer   user_data)
 {
 	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (user_data);
+	gint width;
 
-	if (allocation->width != self->pv->sidebar_width && allocation->width > 1) {
-		if (self->pv->sidebar_width_sig != 0) {
-			g_source_remove (self->pv->sidebar_width_sig);
-			self->pv->sidebar_width_sig = 0;
-		}
+	width = gtk_paned_get_position (GTK_PANED (widget));
+	g_settings_set_int (self->pv->settings, "sidebar-width", width);
 
-		self->pv->sidebar_width = allocation->width;
-		self->pv->sidebar_width_sig = g_idle_add (on_idle_save_sidebar_width, self);
-	}
+	return FALSE;
 }
 
 static void
@@ -523,7 +573,7 @@ on_sidebar_popup_menu (SeahorseSidebar *sidebar,
 	const gchar *name;
 
 	name = G_OBJECT_TYPE_NAME (collection);
-	seahorse_viewer_show_context_menu (SEAHORSE_VIEWER (self), name,
+	seahorse_catalog_show_context_menu (SEAHORSE_CATALOG (self), name,
 	                                   0, gtk_get_current_event_time ());
 }
 
@@ -533,8 +583,27 @@ setup_sidebar (SeahorseKeyManager *self)
 	GtkWidget *area, *panes;
 	GtkActionGroup *actions;
 	GtkAction *action;
+	GList *backends, *l;
 
 	self->pv->sidebar = seahorse_sidebar_new ();
+
+	self->pv->sidebar_width = g_settings_get_int (self->pv->settings, "sidebar-width");
+	panes = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "sidebar-panes");
+	gtk_paned_set_position (GTK_PANED (panes), self->pv->sidebar_width);
+	g_signal_connect (panes, "realize", G_CALLBACK (on_panes_realize), self);
+	g_signal_connect (panes, "unrealize", G_CALLBACK (on_panes_unrealize), self);
+	g_signal_connect (self->pv->sidebar, "context-menu", G_CALLBACK (on_sidebar_popup_menu), self);
+
+	backends = seahorse_sidebar_get_backends (self->pv->sidebar);
+	for (l = backends; l != NULL; l = g_list_next (l)) {
+		actions = NULL;
+		g_object_get (l->data, "actions", &actions, NULL);
+		if (actions != NULL) {
+			seahorse_catalog_include_actions (SEAHORSE_CATALOG (self), actions);
+			g_object_unref (actions);
+		}
+	}
+
 	area = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "sidebar-area");
 	gtk_container_add (GTK_CONTAINER (area), GTK_WIDGET (self->pv->sidebar));
 	gtk_widget_show (GTK_WIDGET (self->pv->sidebar));
@@ -544,28 +613,22 @@ setup_sidebar (SeahorseKeyManager *self)
 	gtk_action_group_add_toggle_actions (actions, SIDEBAR_ACTIONS,
 	                                     G_N_ELEMENTS (SIDEBAR_ACTIONS), self);
 	action = gtk_action_group_get_action (actions, "view-places");
-	g_object_bind_property (action, "active",
-	                        area, "visible",
-	                        G_BINDING_DEFAULT);
-	g_object_bind_property (action, "active",
-	                        self->pv->sidebar, "combined",
-	                        G_BINDING_INVERT_BOOLEAN);
 	g_settings_bind (self->pv->settings, "sidebar-visible",
 	                 action, "active",
 	                 G_SETTINGS_BIND_DEFAULT);
-	seahorse_viewer_include_actions (SEAHORSE_VIEWER (self), actions);
+	g_object_bind_property (action, "active",
+	                        area, "visible",
+	                        G_BINDING_SYNC_CREATE);
+	g_object_bind_property (action, "active",
+	                        self->pv->sidebar, "combined",
+	                        G_BINDING_INVERT_BOOLEAN | G_BINDING_SYNC_CREATE);
+	seahorse_catalog_include_actions (SEAHORSE_CATALOG (self), actions);
 	g_object_unref (actions);
 
 	g_settings_bind (self->pv->settings, "places-selected",
 	                 self->pv->sidebar, "selected-uris",
 	                 G_SETTINGS_BIND_DEFAULT);
 
-	self->pv->sidebar_width = g_settings_get_int (self->pv->settings, "sidebar-width");
-	panes = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "sidebar-panes");
-	gtk_paned_set_position (GTK_PANED (panes), self->pv->sidebar_width);
-	g_signal_connect (self->pv->sidebar, "size_allocate", G_CALLBACK (on_sidebar_panes_size_allocate), self);
-	g_signal_connect (self->pv->sidebar, "context-menu", G_CALLBACK (on_sidebar_popup_menu), self);
-
 	return seahorse_sidebar_get_collection (self->pv->sidebar);
 }
 
@@ -581,26 +644,44 @@ seahorse_key_manager_constructed (GObject *object)
 
 	G_OBJECT_CLASS (seahorse_key_manager_parent_class)->constructed (object);
 
+	gtk_window_set_title (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)), _("Passwords and Keys"));
+
 	self->pv->collection = setup_sidebar (self);
 
-	gtk_window_set_title (seahorse_viewer_get_window (SEAHORSE_VIEWER (self)), _("Passwords and Keys"));
-	
+	/* Init key list & selection settings */
+	self->pv->view = GTK_TREE_VIEW (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "key-list"));
+	g_return_if_fail (self->pv->view != NULL);
+
+	selection = gtk_tree_view_get_selection (self->pv->view);
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+	g_signal_connect (selection, "changed", G_CALLBACK (on_view_selection_changed), self);
+	gtk_widget_realize (GTK_WIDGET (self->pv->view));
+
+	/* Add new key store and associate it */
+	self->pv->store = seahorse_key_manager_store_new (self->pv->collection,
+	                                                  self->pv->view,
+	                                                  &self->pv->pred,
+	                                                  self->pv->settings);
+
+
 	actions = gtk_action_group_new ("general");
 	gtk_action_group_set_translation_domain (actions, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (actions, GENERAL_ACTIONS, G_N_ELEMENTS (GENERAL_ACTIONS), self);
-	seahorse_viewer_include_actions (SEAHORSE_VIEWER (self), actions);
+	seahorse_catalog_include_actions (SEAHORSE_CATALOG (self), actions);
 
 	self->pv->view_actions = gtk_action_group_new ("view");
 	gtk_action_group_set_translation_domain (self->pv->view_actions, GETTEXT_PACKAGE);
 	gtk_action_group_add_radio_actions (self->pv->view_actions, VIEW_RADIO_ACTIONS,
-	                                    G_N_ELEMENTS (VIEW_RADIO_ACTIONS), SHOW_PERSONAL,
+	                                    G_N_ELEMENTS (VIEW_RADIO_ACTIONS), -1,
 	                                    G_CALLBACK (on_view_show_changed), self);
 	action = gtk_action_group_get_action (self->pv->view_actions, "view-personal");
-	seahorse_viewer_include_actions (SEAHORSE_VIEWER (self), self->pv->view_actions);
+	seahorse_catalog_include_actions (SEAHORSE_CATALOG (self), self->pv->view_actions);
+	self->pv->show_action = GTK_RADIO_ACTION (action);
 
 	/* Notify us when settings change */
 	g_signal_connect_object (self->pv->settings, "changed::item-filter",
-	                         G_CALLBACK (on_item_filter_changed), action, 0);
+	                         G_CALLBACK (on_item_filter_changed), self, 0);
+	on_item_filter_changed (self->pv->settings, "item-filter", self);
 
 	/* close event */
 	g_signal_connect_object (seahorse_widget_get_toplevel (SEAHORSE_WIDGET (self)), 
@@ -614,7 +695,7 @@ seahorse_key_manager_constructed (GObject *object)
 	                         "clicked", G_CALLBACK (on_keymanager_new_button), self, 0);
 
 	/* Flush all updates */
-	seahorse_viewer_ensure_updated (SEAHORSE_VIEWER (self));
+	seahorse_catalog_ensure_updated (SEAHORSE_CATALOG (self));
 	
 	/* Find the toolbar */
 	widget = seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "toolbar-placeholder");
@@ -681,37 +762,22 @@ seahorse_key_manager_constructed (GObject *object)
 	                         G_CALLBACK (on_filter_changed), self, 0);
 
 
-	/* Init key list & selection settings */
-	self->pv->view = GTK_TREE_VIEW (seahorse_widget_get_widget (SEAHORSE_WIDGET (self), "key-list"));
-	g_return_if_fail (self->pv->view != NULL);
-
-	selection = gtk_tree_view_get_selection (self->pv->view);
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
-	g_signal_connect (selection, "changed", G_CALLBACK (on_view_selection_changed), self);
-	gtk_widget_realize (GTK_WIDGET (self->pv->view));
-
-	/* Add new key store and associate it */
-	self->pv->store = seahorse_key_manager_store_new (self->pv->collection,
-	                                                  self->pv->view,
-	                                                  &self->pv->pred,
-	                                                  self->pv->settings);
-
 	/* Set focus to the current key list */
 	gtk_widget_grab_focus (GTK_WIDGET (self->pv->view));
 	g_signal_emit_by_name (self, "selection-changed");
 
 	/* To avoid flicker */
-	seahorse_widget_show (SEAHORSE_WIDGET (SEAHORSE_VIEWER (self)));
+	seahorse_widget_show (SEAHORSE_WIDGET (SEAHORSE_CATALOG (self)));
 	
 	/* Setup drops */
-	gtk_drag_dest_set (GTK_WIDGET (seahorse_viewer_get_window (SEAHORSE_VIEWER (self))), 
+	gtk_drag_dest_set (GTK_WIDGET (seahorse_catalog_get_window (SEAHORSE_CATALOG (self))),
 	                   GTK_DEST_DEFAULT_ALL, NULL, 0, GDK_ACTION_COPY);
 	targets = gtk_target_list_new (NULL, 0);
 	gtk_target_list_add_uri_targets (targets, TARGETS_URIS);
 	gtk_target_list_add_text_targets (targets, TARGETS_PLAIN);
-	gtk_drag_dest_set_target_list (GTK_WIDGET (seahorse_viewer_get_window (SEAHORSE_VIEWER (self))), targets);
+	gtk_drag_dest_set_target_list (GTK_WIDGET (seahorse_catalog_get_window (SEAHORSE_CATALOG (self))), targets);
 
-	g_signal_connect_object (seahorse_viewer_get_window (SEAHORSE_VIEWER (self)), "drag-data-received", 
+	g_signal_connect_object (seahorse_catalog_get_window (SEAHORSE_CATALOG (self)), "drag-data-received",
 	                         G_CALLBACK (on_target_drag_data_received), self, 0);
 
 #ifdef REFACTOR_FIRST
@@ -752,15 +818,15 @@ static void
 seahorse_key_manager_class_init (SeahorseKeyManagerClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+	SeahorseCatalogClass *catalog_class = SEAHORSE_CATALOG_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (SeahorseKeyManagerPrivate));
 
 	gobject_class->constructed = seahorse_key_manager_constructed;
 	gobject_class->finalize = seahorse_key_manager_finalize;
 
-	SEAHORSE_VIEWER_CLASS (klass)->get_selected_objects = seahorse_key_manager_get_selected_objects;
-	SEAHORSE_VIEWER_CLASS (klass)->get_selected_places = seahorse_key_manager_get_selected_places;
-	SEAHORSE_VIEWER_CLASS (klass)->get_selected_backends = seahorse_key_manager_get_selected_backends;
+	catalog_class->get_selected_objects = seahorse_key_manager_get_selected_objects;
+	catalog_class->get_focused_place = seahorse_key_manager_get_focused_place;
 }
 
 SeahorseWidget *
